public inbox for linux-kernel@vger.kernel.org
 help / color / mirror / Atom feed
* [PATCH] trace-cmd: Search $TRACE_CMD_PLUGIN_DIR for plugins.
@ 2010-09-29  0:00 David Sharp
  2010-10-20 13:28 ` Steven Rostedt
  0 siblings, 1 reply; 2+ messages in thread
From: David Sharp @ 2010-09-29  0:00 UTC (permalink / raw)
  To: rostedt; +Cc: linux-kernel, mrubin, David Sharp

Allows dynamic specification of the plugin directory so that plugins can be
used when the install prefix cannot be predicted, such as when using a
pre-compiled version of trace-cmd with Autotest.

Signed-off-by: David Sharp <dhsharp@google.com>
---
 trace-util.c |    8 +++++++-
 1 files changed, 7 insertions(+), 1 deletions(-)

diff --git a/trace-util.c b/trace-util.c
index 33dbdf0..9e0ceca 100644
--- a/trace-util.c
+++ b/trace-util.c
@@ -771,6 +771,7 @@ void trace_util_load_plugins(struct pevent *pevent, const char *suffix,
 {
 	char *home;
 	char *path;
+        char *envdir;
 
 	if (tracecmd_disable_plugins)
 		return;
@@ -782,7 +783,12 @@ void trace_util_load_plugins(struct pevent *pevent, const char *suffix,
 					    load_plugin, data);
 #endif
 
-	/* Now let the home directory override the system defaults */
+	/* Next let the environment-set plugin directory override the system defaults */
+	envdir = getenv("TRACE_CMD_PLUGIN_DIR");
+	if (envdir)
+		trace_util_load_plugins_dir(pevent, suffix, envdir, load_plugin, data);
+
+	/* Now let the home directory override the environment or system defaults */
 	home = getenv("HOME");
 
 	if (!home)
-- 
1.7.1


^ permalink raw reply related	[flat|nested] 2+ messages in thread

end of thread, other threads:[~2010-10-20 13:28 UTC | newest]

Thread overview: 2+ messages (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
2010-09-29  0:00 [PATCH] trace-cmd: Search $TRACE_CMD_PLUGIN_DIR for plugins David Sharp
2010-10-20 13:28 ` Steven Rostedt

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox